/*
Copyright (C) 1999/2000 Hendrik Lipka.
All rights reserved.

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation;
either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along with this
program; if not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA or see http://www.gnu.org

If you encounter problems or have a suggestion, please mail to:
hli@hendriklipka.de
*/
package de.hendriklipka.pdfconv;

import jcmdline.*;

import java.io.File;
import java.io.IOException;
import java.util.Collection;
import java.util.Iterator;

public class PDFConv
{
    private static final String VERSION="0.2.0";

    Converter _conv=null;

    public static void main(String[] args)
    {
        try
        {
            PDFConv pc=new PDFConv();
            pc.readParameters(args);
            pc.convert();
        }
        catch (Exception e)
        {
            e.printStackTrace();
            System.exit(1);
        }
        System.exit(0);
    }

    public PDFConv()
    {
        _conv=new Converter();
    }

    private void readParameters(String[] args)
    {
        String helpText="This program reads a PDF file, and saves each page as an image (JPEG or PICT). Additionaly, a HTML, "+
            "BookMaker source file or NTK book source file is written to reference all files.";

        FileParam sourceParam=new FileParam("source", "the PDF input file(s)", FileParam.IS_FILE&FileParam.IS_READABLE, FileParam.REQUIRED, FileParam.MULTI_VALUED);
        StringParam baseNameParam=new StringParam("basename", "the base name for all output files", true);
        IntParam widthParam=new IntParam("maxwidth", "maximum width of a resulting image", 50, 1000, true);
        IntParam heigthParam=new IntParam("maxheigth", "maximum heigth of a resulting image", 50, 1000, true);
        StringParam scaleFactorParam=new StringParam("scalefactor", "how to scale the created images (float value)", true);
        FileParam targetDirParam=new FileParam("targetdir", "where to write the resulting files", FileParam.IS_DIR&FileParam.IS_WRITEABLE, FileParam.OPTIONAL, FileParam.SINGLE_VALUED);
        IntParam qualityParam=new IntParam("quality", "quality of a resulting JPEG image", 10, 100, true);
        BooleanParam pictParam=new BooleanParam("writePICT", "write PICT image files");
        BooleanParam bmpParam=new BooleanParam("writeBMP", "write BMP image files");
        BooleanParam jpegParam=new BooleanParam("writeJPEG", "write JPG image files");
        BooleanParam bookParam=new BooleanParam("writeBook", "write BookMaker file");
        BooleanParam ntkParam=new BooleanParam("writeNTK", "write NTK Book file");
        BooleanParam htmlParam=new BooleanParam("writeHTML", "write HTML file");
        BooleanParam verboseParam=new BooleanParam("verbose", "be verbose");
        BooleanParam debugParam=new BooleanParam("debug", "be very verbose - give debugging information");

        String targetBaseName=null;
        String targetDir="";

        CmdLineHandler cl=
            new VersionCmdLineHandler("V "+VERSION,
                new HelpCmdLineHandler(helpText,
                    "run",
                    "convert PDF files for showing on a Newton",
                    new Parameter[]{baseNameParam, pictParam, bmpParam, jpegParam, bookParam, ntkParam, htmlParam, widthParam,
                                    heigthParam, scaleFactorParam, targetDirParam, qualityParam, verboseParam, debugParam},
                    new Parameter[]{sourceParam},
                    new PosixCmdLineParser()));
        cl.parse(args);

        targetDir=targetDirParam.getValue();
        targetBaseName=baseNameParam.getValue();

        if (null!=targetDir&&0!=targetDir.length())
        {
            targetDir=targetDir.replace('\\', '/');
            if (!targetDir.endsWith("/"))
                targetDir+="/";
            targetDir=targetDir.trim();
            if (0!=targetDir.length())
            {
                _conv.setTargetDir(targetDir);
            }
        }

        if (null!=targetBaseName)
        {
            targetBaseName=targetBaseName.trim();
            if (0!=targetBaseName.length())
                _conv.setBaseName(targetBaseName);
        }

        if (pictParam.isTrue())
            _conv.setWritePICT();
        if (bmpParam.isTrue())
            _conv.setWriteBMP();
        if (jpegParam.isTrue())
            _conv.setWriteJPEG();
        if (htmlParam.isTrue())
            _conv.setWriteHTML();

        if (bookParam.isTrue())
        {
            if (pictParam.isTrue())
                _conv.setWriteBookMac();
            if (bmpParam.isTrue())
                _conv.setWriteBookWin();
            if (!pictParam.isTrue()&&!bmpParam.isTrue())
            {
                _conv.setWriteBookMac();
                _conv.setWriteBookWin();
            }
        }

        if (ntkParam.isTrue())
        {
            if (pictParam.isTrue())
                _conv.setWriteNTKMac();
            if (bmpParam.isTrue())
                _conv.setWriteNTKWin();
            if (!pictParam.isTrue()&&!bmpParam.isTrue())
            {
                _conv.setWriteNTKMac();
                _conv.setWriteNTKWin();
            }
        }

        if (widthParam.isSet())
        {
            _conv.setMaxWidth(widthParam.intValue());
        }
        if (heigthParam.isSet())
            _conv.setMaxHeigth(heigthParam.intValue());
        if (scaleFactorParam.isSet())
        {
            try
            {
                _conv.setScaleFactor(Double.parseDouble(scaleFactorParam.getValue()));
            }
            catch (NumberFormatException e)
            {
                cl.exitUsageError("'-scalefactor' must be a Double value");
            }
        }
        if (qualityParam.isSet())
        {
            if (!jpegParam.isTrue())
                cl.exitUsageError("'-quality' can only be used when writing JPEG files.");
            _conv.setQuality(qualityParam.intValue());
        }

        Collection files=sourceParam.getFiles();
        for (Iterator iterator=files.iterator(); iterator.hasNext();)
        {
            File file=(File)iterator.next();
            _conv.addSourceFile(file);
        }

        _conv.setVerbose(verboseParam.isSet()||debugParam.isSet());
        _conv.setDebug(debugParam.isSet());
    }

    public void convert() throws IOException
    {
        _conv.convert();
    }
}
